Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Empty = Interval{Empty: true}
Functions ¶
This section is empty.
Types ¶
type Interval ¶
type Interval struct {
// Lower is the lower bound of the interval; can be a concrete number or the special constant
// Infinity (interpreted as -infinity)
Lower BoundType
// Upper is the upper bound of the interval; can be a concrete number or the special constant
// Infinity
Upper BoundType
// Empty indicates that this interval is empty
Empty bool
}
Interval is a structure representing an interval of integer numbers, [Lower, Upper]
func NewInterval ¶
Click to show internal directories.
Click to hide internal directories.